#include <libusb-1.0/libusb.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "messages.h"

// program to dump a file over USB
// relies on libusb-1.x

typedef unsigned char uchar;
typedef unsigned short uword;


int main(int argc, char *argv[]) {
	if (argc < 2) {
		printf("Name of file?\n");
		return 0;
	}

	FILE *f = fopen(argv[1], "r");

	struct stat statbuf;
	stat(argv[1], &statbuf);

	union {
		uchar c[8];
		uword w[4];
	}buf;

	if (libusb_init(NULL)) {
		printf("libusb init failed\n");
		libusb_exit(NULL);
		return 0;
	}

	//this is a lazy way to do it, the ID is for obdev's V-USB
	//if there's another device sharing the ID it will get picked up instead
	libusb_device_handle *usbd = libusb_open_device_with_vid_pid(NULL, 0x16c0, 0x5dc);

	if (!usbd) {
		printf("Couldn't find (or open...) device\n");
		libusb_exit(NULL);
		return 0;
	}

	//first send the reset command
	libusb_control_transfer(usbd, LIBUSB_RECIPIENT_DEVICE | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_ENDPOINT_IN,
					MSG_RELOAD, 0, 0, buf.c, 8, 5000);


	int sent = 0;
	int ret = -1;
	int mod = 0;
	uchar buf1[8];
	uchar buf2[8];
	while(!feof(f)) {
		//this actual value really should be used, but there's no harm
		//in sending some junk at the end.
		int actual = fread(buf1, 1, 8, f);
		if (actual == 0)
			break;
		//poll until AVR says to send
		do {
			libusb_control_transfer(usbd, LIBUSB_RECIPIENT_DEVICE | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_ENDPOINT_IN,
					MSG_STATUS, 0, 0, buf.c, 8, 5000);
		} while(buf.c[0] != MSG_SEND);

		ret = libusb_control_transfer(usbd, LIBUSB_RECIPIENT_DEVICE | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_ENDPOINT_OUT,
			MSG_WRITE, 0, 0, buf1, actual, 5000);
		if (ret < 0) {
			printf("Transfer error, control-out returned %i\n", ret);
			return 0;
		}

		sent += ret;

		//read it back to check
		ret = libusb_control_transfer(usbd, LIBUSB_RECIPIENT_DEVICE | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_ENDPOINT_IN,
			MSG_OUT, 0, 0, buf2, 8, 5000);

		if (memcmp(buf1, buf2, 8)) {
			printf("Data read back didn't match!\n");
			int i;
			for (i = 0;i < 8;i++) {
				printf("%x", buf1[i]);
			}
			printf("\n");
			for (i = 0;i < 8;i++) {
				printf("%x", buf2[i]);
			}
			printf("\n");
			//but don't abort... I've had this read back the wrong thing and work anyway
		}
		mod++;

		//don't spam as much for bigger transfers
		if (statbuf.st_size < 1000 || mod == 10) {
			printf("Sent %i bytes of %i\n", sent, statbuf.st_size);
			mod = 0;
		}
	}

	//send the EOF message so it can start running
	libusb_control_transfer(usbd, LIBUSB_RECIPIENT_DEVICE | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_ENDPOINT_IN,
					MSG_EOF, 0, 0, buf.c, 8, 5000);


	printf("All good... probably. Sent %i bytes\n", sent);
	libusb_exit(NULL);

	return 0;
}

